@@ -62,8 +62,8 @@ Because Fiona collections are context managers, they are closed and (in
 writing modes) flush contents to disk when their ``with`` blocks end.
 """
 
-__all__ = []
-__version__ = "0.16"
+__all__ = ['listlayers', 'open', 'prop_width']
+__version__ = "0.16.1"
 
 import os
 from six import string_types
